import React, { useRef, useState } from 'react';
import { PageContainer } from '@ant-design/pro-layout';
import { Alert, Button, Card, message, Space, Modal } from 'antd';
import { UploadOutlined } from '@ant-design/icons';
import School from '@/components/School';
import Step from './Step'
import { read } from './excel'

export default (props) => {
  
  const [visible, setVisible] = useState(false)
  const [schoolId, setSchoolId] = useState()
  const [reading, setReading] = useState(false)

  const workbookRef = useRef()

  const handleFile = () => {
    const input = document.createElement('input')
    input.type = 'file'
    input.accept = 'application/vnd.ms-excel,application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
    input.onchange = (e) => {
      const file = e.target.files[0]
      if (!file) {
        message.warning('请选择文件')
      }

      setReading(true)
      read(file).then((res) => {
        workbookRef.current = res
        setReading(false)
        setVisible(true)
      }).catch((err) => {
        console.error(err)
        setReading(false)
      })
    }
    input.click()
  }

  return (
    <PageContainer>
      <Space direction="vertical" size="large" style={{width: '100%'}}>
        <Alert message="友情提示" description="导入文件数据不要超过 200 列, 6000 行" type="info" closable />
        <Card>
          <Space direction="horizontal" size="large">
            <School
              autoDefault={false}
              value={schoolId}
              onChange={setSchoolId}
              allowClear
              style={{width: '300px'}}
              placeholder="请选择学校"
            ></School>

            <Button
              ghost
              type="primary"
              loading={reading}
              disabled={!schoolId}
              icon={<UploadOutlined />}
              onClick={handleFile}
            >导入</Button>
          </Space>
        </Card>
      </Space>
      <Modal
        title="设置数据内容"
        visible={visible}
        onCancel={() => setVisible(false)}
        footer={null}
        maskClosable={false}
      >
        <Step workbook={workbookRef.current} />
      </Modal>
    </PageContainer>
  )
}
